searchData={"items":[{"type":"module","title":"DomainTwistex.DNS","doc":"Provides pure DNS query operations for domain names.\nHandles various DNS record types including A, CNAME, MX, TXT, and NS records.\nAll functions use Erlang's :inet_res module for DNS resolution.","ref":"DomainTwistex.DNS.html"},{"type":"function","title":"DomainTwistex.DNS.get_mx_records/1","doc":"Retrieves MX (Mail Exchange) records for a domain.","ref":"DomainTwistex.DNS.html#get_mx_records/1"},{"type":"function","title":"Parameters - DomainTwistex.DNS.get_mx_records/1","doc":"* domain - String representing the domain to query","ref":"DomainTwistex.DNS.html#get_mx_records/1-parameters"},{"type":"function","title":"Returns - DomainTwistex.DNS.get_mx_records/1","doc":"* `{:ok, [map]}` - List of maps containing :priority and :server keys\n  * `{:error, :lookup_failed}` - When lookup fails","ref":"DomainTwistex.DNS.html#get_mx_records/1-returns"},{"type":"function","title":"Example - DomainTwistex.DNS.get_mx_records/1","doc":"```\n    iex> DomainTwistex.DNS.get_mx_records(\"example.com\")\n    {:ok, [%{priority: 10, server: \"mail.example.com\"}]}\n    ```","ref":"DomainTwistex.DNS.html#get_mx_records/1-example"},{"type":"function","title":"DomainTwistex.DNS.get_nameservers/1","doc":"Retrieves nameserver information for a domain.","ref":"DomainTwistex.DNS.html#get_nameservers/1"},{"type":"function","title":"Parameters - DomainTwistex.DNS.get_nameservers/1","doc":"* domain - String representing the domain to query","ref":"DomainTwistex.DNS.html#get_nameservers/1-parameters"},{"type":"function","title":"Returns - DomainTwistex.DNS.get_nameservers/1","doc":"* `{:ok, [string]}` - List of nameserver hostnames\n  * `{:error, string}` - Error message if lookup fails","ref":"DomainTwistex.DNS.html#get_nameservers/1-returns"},{"type":"function","title":"Example - DomainTwistex.DNS.get_nameservers/1","doc":"```\n    iex> DomainTwistex.DNS.get_nameservers(\"example.com\")\n    {:ok, [\"ns1.example.com\", \"ns2.example.com\"]}\n    ```","ref":"DomainTwistex.DNS.html#get_nameservers/1-example"},{"type":"function","title":"DomainTwistex.DNS.get_txt_records/1","doc":"Retrieves TXT records for a domain.","ref":"DomainTwistex.DNS.html#get_txt_records/1"},{"type":"function","title":"Parameters - DomainTwistex.DNS.get_txt_records/1","doc":"* domain - String representing the domain to query","ref":"DomainTwistex.DNS.html#get_txt_records/1-parameters"},{"type":"function","title":"Returns - DomainTwistex.DNS.get_txt_records/1","doc":"* `{:ok, [string]}` - List of TXT record strings\n  * `{:error, string}` - Error message if lookup fails","ref":"DomainTwistex.DNS.html#get_txt_records/1-returns"},{"type":"function","title":"Example - DomainTwistex.DNS.get_txt_records/1","doc":"```\n    iex> DomainTwistex.DNS.get_txt_records(\"example.com\")\n    {:ok, [\"v=spf1 -all\"]}\n    ```","ref":"DomainTwistex.DNS.html#get_txt_records/1-example"},{"type":"function","title":"DomainTwistex.DNS.resolve_ips/1","doc":"Resolves IP addresses for a given domain, handling both A and CNAME records.","ref":"DomainTwistex.DNS.html#resolve_ips/1"},{"type":"function","title":"Parameters - DomainTwistex.DNS.resolve_ips/1","doc":"* domain - String representing the domain to resolve","ref":"DomainTwistex.DNS.html#resolve_ips/1-parameters"},{"type":"function","title":"Returns - DomainTwistex.DNS.resolve_ips/1","doc":"* `{:ok, %{ips: [string], cname: string | nil}}` - Resolved DNS information\n  * `{:error, :no_records}` - When no records are found\n  * `{:error, :invalid_response}` - When DNS lookup returns invalid response","ref":"DomainTwistex.DNS.html#resolve_ips/1-returns"},{"type":"function","title":"Example - DomainTwistex.DNS.resolve_ips/1","doc":"```\n    iex> DomainTwistex.DNS.resolve_ips(\"example.com\")\n    {:ok, %{ips: [\"93.184.216.34\"], cname: nil}}\n    ```","ref":"DomainTwistex.DNS.html#resolve_ips/1-example"},{"type":"module","title":"DomainTwistex.Twist","doc":"Provides high-level domain analysis functionality by combining permutation generation\nwith concurrent domain validation checks.\n\nThis module builds upon the DomainTwistex.Utils functionality to provide comprehensive\ndomain analysis tools for identifying potential typosquatting and domain abuse scenarios.","ref":"DomainTwistex.Twist.html"},{"type":"function","title":"DomainTwistex.Twist.analyze_domain/2","doc":"Analyzes a domain by generating permutations and checking them concurrently.\n\nThis function combines permutation generation with comprehensive domain validation,\nrunning checks in parallel for improved performance. It handles DNS resolution,\nserver checking, and MX record validation for each permutation.","ref":"DomainTwistex.Twist.html#analyze_domain/2"},{"type":"function","title":"Parameters - DomainTwistex.Twist.analyze_domain/2","doc":"* domain - String representing the base domain to analyze (e.g., \"example.com\")\n  * opts - Keyword list of options:\n    * max_concurrency: Maximum number of concurrent tasks (default: System.schedulers_online() * 2)\n    * timeout: Timeout in milliseconds for each task (default: 5000)\n    * ordered: Whether to maintain permutation order in results (default: false)","ref":"DomainTwistex.Twist.html#analyze_domain/2-parameters"},{"type":"function","title":"Returns - DomainTwistex.Twist.analyze_domain/2","doc":"* List of maps, each containing validated domain information:\n    * :kind - Type of permutation (e.g., \"Homoglyph\", \"Bitsquatting\")\n    * :fqdn - Fully qualified domain name\n    * :tld - Top-level domain\n    * :ip_addresses - List of resolved IP addresses\n    * :mx_records - List of MX record information\n    * :resolvable - Boolean indicating if domain resolves\n    * Additional DNS and server information","ref":"DomainTwistex.Twist.html#analyze_domain/2-returns"},{"type":"function","title":"Examples - DomainTwistex.Twist.analyze_domain/2","doc":"```elixir\n    # Basic usage\n    iex> DomainTwistex.Twist.analyze_domain(\"google.com\")\n    [\n      %{\n        kind: \"Tld\",\n        fqdn: \"google.co.uz\",\n        ip_addresses: [\"173.194.219.99\", \"173.194.219.103\"],\n        mx_records: [%{priority: 0, server: \".\"}],\n        resolvable: true,\n        tld: \"co.uz\"\n      },\n      # ... additional results\n    ]\n\n    # With custom options\n    iex> DomainTwistex.Twist.analyze_domain(\"example.com\", max_concurrency: 50, timeout: 10_000)\n    ```","ref":"DomainTwistex.Twist.html#analyze_domain/2-examples"},{"type":"function","title":"Performance Considerations - DomainTwistex.Twist.analyze_domain/2","doc":"* Higher max_concurrency values can improve speed but may trigger rate limiting\n  * Timeout values should be adjusted based on network conditions\n  * Setting ordered: true may impact performance for large result sets","ref":"DomainTwistex.Twist.html#analyze_domain/2-performance-considerations"},{"type":"function","title":"DomainTwistex.Twist.get_live_mx_domains/2","doc":"Filters domain analysis results to return only those with valid MX records.\n\nThis function is particularly useful for identifying potentially malicious domains\nthat are set up for email operations, which could be used for phishing attacks.","ref":"DomainTwistex.Twist.html#get_live_mx_domains/2"},{"type":"function","title":"Parameters - DomainTwistex.Twist.get_live_mx_domains/2","doc":"* domain - String representing the base domain to analyze\n  * opts - Keyword list of options (same as analyze_domain/2)","ref":"DomainTwistex.Twist.html#get_live_mx_domains/2-parameters"},{"type":"function","title":"Returns - DomainTwistex.Twist.get_live_mx_domains/2","doc":"* List of maps containing only domains with valid MX records\n  * Empty list if no domains with MX records are found or on error","ref":"DomainTwistex.Twist.html#get_live_mx_domains/2-returns"},{"type":"function","title":"Examples - DomainTwistex.Twist.get_live_mx_domains/2","doc":"```elixir\n    iex> DomainTwistex.Twist.get_live_mx_domains(\"google.com\", max_concurrency: 50)\n    [\n      %{\n        kind: \"Tld\",\n        mx_records: [%{priority: 0, server: \"smtp.google.com\"}],\n        fqdn: \"google.lt\",\n        resolvable: true,\n        ip_addresses: [\"172.217.215.94\"],\n        tld: \"lt\"\n      },\n      # ... additional results\n    ]\n    ```","ref":"DomainTwistex.Twist.html#get_live_mx_domains/2-examples"},{"type":"function","title":"Error Handling - DomainTwistex.Twist.get_live_mx_domains/2","doc":"* Returns an empty list if any errors occur during processing\n  * Logs errors to console for debugging purposes","ref":"DomainTwistex.Twist.html#get_live_mx_domains/2-error-handling"},{"type":"module","title":"DomainTwistex.Utils","doc":"DomainTwistEx provides domain permutation generation and validation utilities.\nCombines Rust NIFs for permutation generation with domain validation and server checking capabilities.","ref":"DomainTwistex.Utils.html"},{"type":"module","title":"Prerequisites - DomainTwistex.Utils","doc":"- Rust and Cargo must be installed on your system\n  Install from https://rustup.rs/\n\nIf you see a `:enoent` error during compilation, ensure Rust/Cargo is installed\nand available in your PATH.","ref":"DomainTwistex.Utils.html#module-prerequisites"},{"type":"function","title":"DomainTwistex.Utils.check_domain/1","doc":"Performs comprehensive domain validation checks including DNS and server availability.","ref":"DomainTwistex.Utils.html#check_domain/1"},{"type":"function","title":"Parameters - DomainTwistex.Utils.check_domain/1","doc":"* permutation - Map containing at least :fqdn and :tld keys","ref":"DomainTwistex.Utils.html#check_domain/1-parameters"},{"type":"function","title":"Returns - DomainTwistex.Utils.check_domain/1","doc":"* `{:ok, map}` - Successfully checked domain with all information\n  * `{:error, binary}` - Error message when checks fail\n  * `{:error, :not_resolvable}` - When domain cannot be resolved","ref":"DomainTwistex.Utils.html#check_domain/1-returns"},{"type":"function","title":"Example - DomainTwistex.Utils.check_domain/1","doc":"```\n    iex> permutation = %{fqdn: \"example.com\", tld: \"com\"}\n    iex> DomainTwistex.Utils.check_domain(permutation)\n    {:ok, %{\n      resolvable: true,\n      ip_addresses: [\"93.184.216.34\"],\n      mx_records: [%{priority: 10, server: \"mail.example.com\"}],\n      txt_records: [\"v=spf1 -all\"],\n      server_response: %{status_code: \"200\", server: \"ECS\"},\n      nameservers: [\"ns1.example.com\", \"ns2.example.com\"]\n    }}\n    ```","ref":"DomainTwistex.Utils.html#check_domain/1-example"},{"type":"function","title":"DomainTwistex.Utils.check_server/1","doc":"Performs a basic HTTP check on a domain's web server.","ref":"DomainTwistex.Utils.html#check_server/1"},{"type":"function","title":"Parameters - DomainTwistex.Utils.check_server/1","doc":"* domain - String representing the domain to check","ref":"DomainTwistex.Utils.html#check_server/1-parameters"},{"type":"function","title":"Returns - DomainTwistex.Utils.check_server/1","doc":"* map containing server response information or error details","ref":"DomainTwistex.Utils.html#check_server/1-returns"},{"type":"function","title":"Example - DomainTwistex.Utils.check_server/1","doc":"```\n    iex> DomainTwistex.Utils.check_server(\"example.com\")\n    %{\n      status_code: \"200\",\n      server: \"ECS\",\n      headers: %{\"Server\" => \"ECS\", \"Content-Type\" => \"text/html\"}\n    }\n    ```","ref":"DomainTwistex.Utils.html#check_server/1-example"},{"type":"function","title":"DomainTwistex.Utils.generate_permutations/1","doc":"Generates domain permutations using the Twistrs Rust library.\n\nThis function is implemented as a Native Implemented Function (NIF) that interfaces \nwith the Twistrs Rust library for efficient domain permutation generation.","ref":"DomainTwistex.Utils.html#generate_permutations/1"},{"type":"function","title":"Attribution - DomainTwistex.Utils.generate_permutations/1","doc":"This NIF wraps functionality from the Twistrs library:\nhttps://github.com/haveibeensquatted/twistrs","ref":"DomainTwistex.Utils.html#generate_permutations/1-attribution"},{"type":"function","title":"Parameters - DomainTwistex.Utils.generate_permutations/1","doc":"* domain - String representing the domain to generate permutations for","ref":"DomainTwistex.Utils.html#generate_permutations/1-parameters"},{"type":"function","title":"Returns - DomainTwistex.Utils.generate_permutations/1","doc":"List of generated domain permutation strings","ref":"DomainTwistex.Utils.html#generate_permutations/1-returns"},{"type":"function","title":"Examples - DomainTwistex.Utils.generate_permutations/1","doc":"```\n    iex(1)> DomainTwistex.Utils.generate_permutations(\"google.com\")\n    [\n      %{kind: \"Keyword\", fqdn: \"servicegoogle.com\", tld: \"com\"},\n      %{kind: \"Homoglyph\", fqdn: \"ğöögle.com\", tld: \"com\"},\n      # ...\n    ]\n    ```","ref":"DomainTwistex.Utils.html#generate_permutations/1-examples"},{"type":"function","title":"DomainTwistex.Utils.validate_domain_resolution/2","doc":"Validates and resolves domain information while checking for TLD-related issues.","ref":"DomainTwistex.Utils.html#validate_domain_resolution/2"},{"type":"function","title":"Parameters - DomainTwistex.Utils.validate_domain_resolution/2","doc":"* domain - String representing the domain to check\n  * tld - String representing the top-level domain to validate against","ref":"DomainTwistex.Utils.html#validate_domain_resolution/2-parameters"},{"type":"function","title":"Returns - DomainTwistex.Utils.validate_domain_resolution/2","doc":"* `{:ok, [string]}` - List of valid IP addresses\n  * `{:error, reason}` - Error message when validation fails","ref":"DomainTwistex.Utils.html#validate_domain_resolution/2-returns"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}